/** \file icons.h
    \brief XPM info for the toolbar button icons
    \ingroup gerbv
*/

/* -------------------  Zoom tool icon  -------------------------- */
/* GdkPixbuf RGBA C-Source image dump */
#ifdef __SUNPRO_C
#pragma align 4 (lzoom)
#endif
#ifdef __GNUC__
static const guint8 lzoom[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 lzoom[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0IIIN444\243---\335))"
  ")\373&&&\373&&&\335&&&\243555N\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0]]]2...\300000\377sss\377\241\241\241\377\264\264\264\377\262\262"
  "\262\377\235\235\235\377ggg\377\40\40\40\377\34\34\34\3007772\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0@@@N'''\373aaa\377\264\264\264\377\312\312\312\377\317\317"
  "\317\377\320\320\320\377\316\316\316\377\311\311\311\377\301\301\301"
  "\377\247\247\247\377LLL\377\23\23\23\373###N\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377OOO2\"\"\"\373uu"
  "u\377\312\312\312\377\323\323\323\377\333\333\333\377\347\347\347\377"
  "\357\357\357\377\363\363\363\377\361\361\361\377\345\345\345\377\322"
  "\322\322\377\274\274\274\377^^^\377\20\20\20\373$$$2\0\0\0\0\0\0\0\377"
  "\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377!!!\300888\377"
  "\314\314\314\377\205\205\205\377\345\345\345\377\227\227\227\377\372"
  "\372\372\377\233\233\233\377\372\372\372\377\231\231\231\377\365\365"
  "\365\377\224\224\224\377\341\341\341\377xxx\377CCC\377\6\6\6\377\0\0"
  "\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""000N\37\37"
  "\37\377\271\271\271\377\326\326\326\377\347\347\347\377\371\371\371\377"
  "\373\373\373\377\375\375\375\377\375\375\375\377\374\374\374\377\373"
  "\373\373\377\370\370\370\377\362\362\362\377\354\354\354\377\344\344"
  "\344\377\253\253\253\377\16\16\16\377\22\22\22N\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\21\21\21\377mmm\377\322\322\322\377\341\341"
  "\341\377\365\365\365\377\372\372\372\377\375\375\375\377\376\376\376"
  "\377\376\376\376\377\375\375\375\377\374\374\374\377\371\371\371\377"
  "\365\365\365\377\356\356\356\377\346\346\346\377\333\333\333\377WWW\377"
  "\11\11\11\243\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\24\24"
  "\24\335\250\250\250\377\330\330\330\377\356\356\356\377\366\366\366\377"
  "\371\371\371\377\374\374\374\377\376\376\376\377\376\376\376\377\375"
  "\375\375\377\373\373\373\377\370\370\370\377\364\364\364\377\356\356"
  "\356\377\346\346\346\377\334\334\334\377\233\233\233\377\6\6\6\335\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20\20\20\377\305\305\305"
  "\377\337\337\337\377\357\357\357\377\365\365\365\377\370\370\370\377"
  "\373\373\373\377\375\375\375\377\375\375\375\377\374\374\374\377\372"
  "\372\372\377\367\367\367\377\362\362\362\377\355\355\355\377\345\345"
  "\345\377\333\333\333\377\277\277\277\377\6\6\6\373\0\0\0\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16\16\16\373\306\306\306\377\343\343"
  "\343\377\354\354\354\377\362\362\362\377\365\365\365\377\370\370\370"
  "\377\372\372\372\377\372\372\372\377\372\372\372\377\367\367\367\377"
  "\364\364\364\377\360\360\360\377\352\352\352\377\340\340\340\377\327"
  "\327\327\377\272\272\272\377\5\5\5\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\11\11\11\377\245\245\245\377\341\341\341\377\347\347"
  "\347\377\355\355\355\377\361\361\361\377\364\364\364\377\366\366\366"
  "\377\366\366\366\377\365\365\365\377\363\363\363\377\357\357\357\377"
  "\354\354\354\377\344\344\344\377\333\333\333\377\321\321\321\377\223"
  "\223\223\377\2\2\2\335\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\12\12\12\243___\377\331\331\331\377\341\341\341\377\346\346\346"
  "\377\353\353\353\377\356\356\356\377\357\357\357\377\357\357\357\377"
  "\356\356\356\377\355\355\355\377\351\351\351\377\344\344\344\377\333"
  "\333\333\377\324\324\324\377\312\312\312\377LLL\377\0\0\0\243\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\3\3\377\12\12\12\377\264\264"
  "\264\377\330\330\330\377\334\334\334\377\342\342\342\377\345\345\345"
  "\377\346\346\346\377\346\346\346\377\347\347\347\377\343\343\343\377"
  "\337\337\337\377\332\332\332\377\324\324\324\377\313\313\313\377\241"
  "\241\241\377\2\2\2\377\0\0\0N\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\37\6\6\6\300;;;\377\314\314\314\377\322\322\322\377"
  "\324\324\324\377\332\332\332\377\333\333\333\377\332\332\332\377\333"
  "\333\333\377\330\330\330\377\325\325\325\377\320\320\320\377\310\310"
  "\310\377\275\275\275\377...\377\0\0\0\300\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\5\5\5""2\5\5\5\373QQQ\377\302"
  "\302\302\377\307\307\307\377\313\313\313\377\314\314\314\377\315\315"
  "\315\377\313\313\313\377\313\313\313\377\310\310\310\377\302\302\302"
  "\377\270\270\270\377EEE\377\0\0\0\373\0\0\0K\0\0\0\0\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\37\3\3\3N\3\3\3\373"
  "111\377\231\231\231\377\273\273\273\377\275\275\275\377\274\274\274\377"
  "\274\274\274\377\274\274\274\377\266\266\266\377\220\220\220\377+++\377"
  "\0\0\0\373\0\0\0\361\0\0\0\362\0\0\0g\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\37\0\0\0""2\1\1\1\300\3\3\3"
  "\377AAA\377zzz\377\232\232\232\377\232\232\232\377www\377<<<\377\0\0"
  "\0\377\0\0\0\300\0\0\0""2\0\0\0\337\0\0\0\360\0\0\0\363\0\0\0\377\0\0"
  "\0L\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\37\0\0\0N\0\0\0\243\0\0\0\335\0\0\0\373\0\0\0\373\0\0\0\335\0\0"
  "\0\243\0\0\0N\0\0\0:\0\0\0\37\0\0\0\37\40\40\40\363\40\40\40\364\0\0"
  "\0\366\0\0\0\361\0\0\0:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\37\0\0\0\37\0\0\0\37\0\0\0\37\0\0"
  "\0\37\0\0\0\37\0\0\0\37\0\0\0\0\0\0\0\0\0\0\0\37\0\0\0\354hhh\373\0\0"
  "\0\377\0\0\0\362\0\0\0\366\0\0\0\37\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\37\0\0\0\363yyy\375"
  ":::\374\0\0\0\363\0\0\0\364\0\0\0\37\0\0\0\377\0\0\0\377\0\0\0\0\0\0"
  "\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0"
  "\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\377\0\0"
  "\0\37\0\0\0\377\0\0\0\377\37\37\37\373\0\0\0\364\0\0\0\37\0\0\0\377\0"
  "\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\37\0\0\0\377\0\0\0\377\0\0\0\375\0\0\0\77\0\0\0\37\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\37\0\0\0\37\0\0\0\37\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* -------------------  Measure tool icon  ------------------- */
/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (ruler)
#endif
#ifdef __GNUC__
static const guint8 ruler[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 ruler[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1024) */
  "\0\0\4\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (64) */
  "\0\0\0@"
  /* width (16) */
  "\0\0\0\20"
  /* height (16) */
  "\0\0\0\20"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\377\0\0\0\0\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\377\0\0\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\377\0\0\0\0\0"
  "\0\0\0\377\0\0\377\0\0\0\0\377\0\0\377\0\0\0\0\377\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0"
  "\0\0\0\0\377\0\0\377\0\0\0\0\377\0\0\377\0\0\0\0\377\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0"};




/* -------------------  Move tool icon  -------------------------- */
/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (move)
#endif
#ifdef __GNUC__
static const guint8 move[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 move[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1936) */
  "\0\0\7\250"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (88) */
  "\0\0\0X"
  /* width (22) */
  "\0\0\0\26"
  /* height (22) */
  "\0\0\0\26"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\31\40J\207\377"
  "\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\40J\207\31\40J\207\377r\237\317\377\40J\207\377\40"
  "J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\40J\207\31\40J\207\377r\237\317\377L|\265\377r\237\317\377\40J\207\377"
  "\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207"
  "\377r\237\317\377L|\265\377L|\265\377L|\265\377r\237\317\377\40J\207"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\377"
  "\40J\207\377\40J\207\377S\203\272\377\40J\207\377\40J\207\377\40J\207"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\40J\207\377Y\210\276\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\40J\207\31\40J\207\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\40"
  "J\207\377b\221\304\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\377"
  "\40J\207\377\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\40J\207\31\40J\207\377r\237\317\377\40J\207\377\0\0\0\0\0\0\0\0\0"
  "\0\0\0\40J\207\377r\237\317\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\40"
  "J\207\377r\237\317\377\40J\207\377\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\40J\207\31\40J\207\377r\237\317\377L|\265\377\40J\207\377\40"
  "J\207\377\40J\207\377\40J\207\377\40J\207\377r\237\317\377\40J\207\377"
  "\40J\207\377\40J\207\377\40J\207\377\40J\207\377L|\265\377r\237\317\377"
  "\40J\207\377\40J\207\31\0\0\0\0\0\0\0\0\40J\207\31\40J\207\377r\237\317"
  "\377L|\265\377L|\265\377S\203\272\377Y\210\276\377b\221\304\377r\237"
  "\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377b\221\304"
  "\377Y\210\276\377S\203\272\377L|\265\377L|\265\377r\237\317\377\40J\207"
  "\377\40J\207\31\0\0\0\0\0\0\0\0\40J\207\31\40J\207\377r\237\317\377L"
  "|\265\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377"
  "r\237\317\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207"
  "\377L|\265\377r\237\317\377\40J\207\377\40J\207\31\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\40J\207\31\40J\207\377r\237\317\377\40J\207\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\40J\207\377r\237\317\377\40J\207\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\40J\207\377r\237\317\377\40J\207\377\40J\207\31\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\31\40J\207\377\40J\207"
  "\377\0\0\0\0\0\0\0\1\0\0\0\1\40J\207\377b\221\304\377\40J\207\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\40J\207\377\40J\207\377\40J\207\31\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\1\0\0\0\3\0"
  "\0\0\6\0\0\0\10\0\0\0\11\40J\207\377Y\210\276\377\40J\207\377\0\0\0\12"
  "\0\0\0\6\0\0\0\5\0\0\0\4\0\0\0\3\0\0\0\2\0\0\0\2\0\0\0\1\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\1\0\0\0\2\0\0\0\5\0\0\0\10\0\0\0\16\0\0\0\26\40J\207"
  "\377\40J\207\377\40J\207\377S\203\272\377\40J\207\377\40J\207\377\40"
  "J\207\377\0\0\0\26\0\0\0\20\0\0\0\14\0\0\0\11\0\0\0\6\0\0\0\3\0\0\0\1"
  "\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0\7\0\0\0\16\0\0\0\25\0\0\0!\0\0\0-\40J"
  "\207\377r\237\317\377L|\265\377L|\265\377L|\265\377r\237\317\377\40J"
  "\207\377\0\0\0""1\0\0\0%\0\0\0\32\0\0\0\22\0\0\0\12\0\0\0\5\0\0\0\1\0"
  "\0\0\0\0\0\0\1\0\0\0\4\0\0\0\13\0\0\0\25\0\0\0\37\0\0\0.\0\0\0:\11\25"
  "'V\40J\207\377r\237\317\377L|\265\377r\237\317\377\40J\207\377\10\24"
  "%[\0\0\0\77\0\0\0""0\0\0\0\40\0\0\0\23\0\0\0\14\0\0\0\5\0\0\0\1\0\0\0"
  "\0\0\0\0\1\0\0\0\3\0\0\0\11\0\0\0\22\0\0\0\35\0\0\0+\0\0\0""6\0\0\0\77"
  "\10\24%[\40J\207\377r\237\317\377\40J\207\377\10\23#^\0\0\0D\0\0\0""9"
  "\0\0\0*\0\0\0\31\0\0\0\16\0\0\0\7\0\0\0\3\0\0\0\1\0\0\0\0\0\0\0\0\0\0"
  "\0\2\0\0\0\4\0\0\0\11\0\0\0\21\0\0\0\32\0\0\0!\0\0\0(\0\0\0""1\12\30"
  ",L\40J\207\377\12\30+M\0\0\0""4\0\0\0+\0\0\0!\0\0\0\25\0\0\0\14\0\0\0"
  "\5\0\0\0\2\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\2\0"
  "\0\0\5\0\0\0\11\0\0\0\13\0\0\0\16\0\0\0\21\0\0\0\26\21(I.\0\0\0\25\0"
  "\0\0\22\0\0\0\15\0\0\0\12\0\0\0\7\0\0\0\3\0\0\0\1\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\2"
  "\0\0\0\2\0\0\0\2\0\0\0\3\0\0\0\3\0\0\0\2\0\0\0\2\0\0\0\1\0\0\0\1\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* -------------------  Pointer tool icon  -------------------------- */
/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (pointer)
#endif
#ifdef __GNUC__
static const guint8 pointer[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 pointer[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\363\363\363"
  "\226\377\377\377(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\377\364\364"
  "\364\354\377\377\377\37\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\376sss\374\364\364"
  "\364\345\377\377\377\27\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\376\376\376\376\1\1\1\377\204\204\204\372\363"
  "\363\363\333\377\377\377\20\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\376\376\376\375\2\2\2\377\0\0\0\377\225\225\225\370"
  "\362\362\362\321\377\377\377\13\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\375\375\375\375\3\3\3\377\0\0\0\377\1\1\1\377\245\245\245\366\362"
  "\362\362\303\377\377\377\6\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\375\375\375"
  "\374\4\4\4\377\0\0\0\377\0\0\0\377\3\3\3\377\264\264\264\365\362\362"
  "\362\265\377\377\377\3\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\374\374\374\374\5\5\5\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\6\6\6\377\302\302\302\364\363\363\363\245"
  "\377\377\377\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\374\374\374\374\6\6\6\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\13\13\13\377\316\316\316\364\365\365\365\224\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\374\374\374"
  "\373\7\7\7\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\20\20"
  "\20\377\331\331\331\364\365\365\365\202\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\373\373\373\373\10\10\10\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\26\26\26\377\343\343\343"
  "\364\370\370\370o\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\373\373\373"
  "\372\11\11\11\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\36\36\36\377\352\352\352\364\374\374\374^\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\372\372\372\372\12\12\12\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\24\24\24\377\31\31\31\377\23\23\23\377"
  "444\377\362\362\362\366\377\377\377O\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\372\372\372\371"
  "\13\13\13\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\3\3\3\377\361\361"
  "\361\372\371\371\371\366\370\370\370\366\372\372\372\371\375\375\375"
  "\374\362\362\362\305\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\372\372\372\370\14\14\14\377\0\0\0"
  "\377:::\377nnn\370\0\0\0\377\0\0\0\377\224\224\224\370\362\362\362\243"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\371\371\371\370\15\15\15\377(((\377\360\360\360\366\371\371\371\371"
  "\20\20\20\377\0\0\0\377\16\16\16\377\356\356\356\365\377\377\3776\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\371\371\371\370"
  "'''\377\347\347\347\365\374\374\374_\356\356\356\276ZZZ\377\0\0\0\377"
  "\0\0\0\377ZZZ\376\362\362\362\326\377\377\377\2\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\371\371\371\367\337\337\337\366\365\365\365}\377"
  "\377\377\0\377\377\377a\262\262\262\363\0\0\0\377\0\0\0\377\0\0\0\377"
  "\311\311\311\362\375\375\375g\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\372\372\372\362\362\362\362\234\377\377\377\0\377\377\377\0\377\377"
  "\377\24\366\366\366\370\7\7\7\377\0\0\0\377\0\0\0\377...\377\367\367"
  "\367\363\377\377\377\17\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\24\377"
  "\377\377\2\377\377\377\0\377\377\377\0\377\377\377\0\355\355\355\320"
  "JJJ\377\11\11\11\377lll\376\351\351\351\364\356\356\356\305\377\377\377"
  "\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\373\373\373s\324\324\324\372\360\360\360"
  "\366\356\356\356\270\377\377\3773\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\24\366\366\366\207\377\377\377(\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"};


